@@ -8,8 +8,10 @@
 package Crypt::DES;
 
 require Exporter;
+require DynaLoader;
+use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
 
-@ISA = (Exporter, DynaLoader);
+@ISA = qw(Exporter DynaLoader);
 
 # Items to export into callers namespace by default
 @EXPORT =	qw();
@@ -17,14 +19,12 @@ require Exporter;
 # Other items we are prepared to export if requested
 @EXPORT_OK =	qw();
 
-$VERSION = '2.00';
-bootstrap Crypt::DES;
-
-package DES;
+$VERSION = '2.05_001';
+$XS_VERSION = $VERSION
+bootstrap Crypt::DES $XS_VERSION;
 
 use strict;
 use Carp;
-use constant BLKSIZE => 8;
 
 sub usage
 {
@@ -34,8 +34,8 @@ sub usage
 }
 
 
-sub blocksize { BLKSIZE; }
-sub keysize { BLKSIZE; }
+sub blocksize { 8; }
+sub keysize   { 8; }
 
 sub new
 {
@@ -56,8 +56,6 @@ sub encrypt
 
 	my ($self,$data) = @_;
 	return Crypt::DES::crypt($data, $data, $self->{'ks'}, 1);
-
-	#return $data;
 }
 
 sub decrypt
@@ -66,8 +64,6 @@ sub decrypt
 
 	my ($self,$data) = @_;
 	return Crypt::DES::crypt($data, $data, $self->{'ks'}, 0);
-
-	#return $data;
 }
 
 1;
@@ -85,7 +81,7 @@ Crypt::DES - Perl DES encryption module
 
 =head1 DESCRIPTION
 
-The module implements the Crypt::BlockCipher interface,
+The module implements the Crypt::CBC interface,
 which has the following methods
 
 =over 4
@@ -148,9 +144,9 @@ blocks.  If you're intending to encrypt larger blocks or entire files,
 please use Crypt::CBC in conjunction with this module.  See the
 Crypt::CBC documentation for proper syntax and use.
 
-Also note that the DES algorithm is, by todays standard, weak 
+Also note that the DES algorithm is, by today's standard, weak 
 encryption.  Crypt::Blowfish is highly recommended if you're
-interested in using strong encryption.
+interested in using strong encryption and a faster algorithm. 
 
 =head1 SEE ALSO
 
@@ -167,7 +163,7 @@ and is copyright of, Eric Young (eay@mincom.oz.au).
 Other parts of the perl extension and module are
 copyright of Systemics Ltd ( http://www.systemics.com/ ).
 Cross-platform work and packaging for single algorithm 
-distribution is Copyright of W3Works, LLC.
+distribution is copyright of W3Works, LLC.
 
 =head1 MAINTAINER
 
